Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(195)

Unified Diff: third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h

Issue 2277713002: Rename CustomElementsRegistry to CustomElementRegistry (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h
diff --git a/third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h b/third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h
index 1a34b376eaa401996c609988f3bb97b02ec62509..0a85efc1cd46f5405d6e4ee36b1788dc6c888bd9 100644
--- a/third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h
+++ b/third_party/WebKit/Source/core/dom/custom/CustomElementDefinitionBuilder.h
@@ -13,13 +13,13 @@ namespace blink {
class CustomElementDefinition;
class CustomElementDescriptor;
-class CustomElementsRegistry;
+class CustomElementRegistry;
class ExceptionState;
class ScriptState;
class ScriptValue;
// Implement CustomElementDefinitionBuilder to provide
// technology-specific steps for CustomElementsRegistry.define.
// https://html.spec.whatwg.org/multipage/scripting.html#dom-customelementsregistry-define
class CORE_EXPORT CustomElementDefinitionBuilder {
STACK_ALLOCATED();
@@ -28,7 +28,7 @@ public:
CustomElementDefinitionBuilder() { }
// This API necessarily sounds JavaScript specific; this implements
// some steps of the CustomElementsRegistry.define process, which
// are defined in terms of JavaScript.
// Check the constructor is valid. Return false if processing
@@ -13,13 +13,13 @@ namespace blink {
class ScriptValue;
// Implement CustomElementDefinitionBuilder to provide
-// technology-specific steps for CustomElementsRegistry.define.
+// technology-specific steps for CustomElementRegistry.define.
// https://html.spec.whatwg.org/multipage/scripting.html#dom-customelementsregistry-define
class CORE_EXPORT CustomElementDefinitionBuilder {
@@ -28,7 +28,7 @@ public:
CustomElementDefinitionBuilder() { }
// This API necessarily sounds JavaScript specific; this implements
- // some steps of the CustomElementsRegistry.define process, which
+ // some steps of the CustomElementRegistry.define process, which
// are defined in terms of JavaScript.
// Check the constructor is valid. Return false if processing

Powered by Google App Engine
This is Rietveld 408576698